AstraGeek — Генератор карт

# Генератор карт неба

Настройте параметры и получите PDF со звёздной картой для наблюдений

Тип проекции
Место и время наблюдения
📍 Широта (°)
📍 Долгота (°)
🕐 Дата и время наблюдения
Область и ориентация
⭐ Созвездие (код IAU)
🔭 Угол зрения FOV (°)
🔄 Поворот камеры (°)
📐 Соотношение сторон
🕐 Дата и время наблюдения
Предельная звёздная величина
💫 Предельная звездная величина (чем больше — тем больше звёзд)
5.5
Дополнительные элементы
Быстрые наборы: выберите пресет или отметьте нужное вручную
Эклиптика Небесный экватор Галактический экватор Планеты Экваториальная сетка Линии созвездий Названия созвездий Засечки осей Стороны света
Информация о наблюдении
Добавить ответы
Добавляет блок с датой, звёздным временем и координатами места в нижнюю часть страницы-задания.
Время наблюдения : —
Звёздное время : рассчитывается автоматически
Координаты : —
Генерируем карту, это займёт несколько секунд…